package main

import (
	"html/template"
	"log"
	"net/http"

	"streifling.com/jason/sicherheitsunterweisung/packages/data"
	"streifling.com/jason/sicherheitsunterweisung/packages/server"
)

func main() {
	logins := make([]string, 0)

	db, err := data.OpenDB("sicherheitsunterweisung")
	if err != nil {
		log.Fatalln(err)
	}

	mux := http.NewServeMux()
	mux.Handle("/static/", http.StripPrefix("/static/", http.FileServer(http.Dir("static/"))))
	mux.HandleFunc("/", func(w http.ResponseWriter, r *http.Request) {
		template.Must(template.ParseFiles("templates/index.html", "templates/login.html")).Execute(w, nil)
	})
	mux.HandleFunc("/search/", server.DisplaySearchResults(db))
	mux.HandleFunc("/new-briefing/", server.DisplayInstructorForm())
	mux.HandleFunc("/add-participant/", server.AddParticipant(&logins))
	mux.HandleFunc("/submit-form/", server.SubmitBriefingForm(db, &logins))
	mux.HandleFunc("/internal-login/", server.DisplayTable(db))
	mux.HandleFunc("/external-login/", server.DisplayParticipantForm(&logins))

	log.Fatalln(http.ListenAndServe(":8080", mux))
}
